@@ -18,7 +18,7 @@ def zsplit(s):
         return []
 
 
-def no_git_env():
+def no_git_env(_env=None):
     # Too many bugs dealing with environment variables and GIT:
     # https://github.com/pre-commit/pre-commit/issues/300
     # In git 2.6.3 (maybe others), git exports GIT_WORK_TREE while running
@@ -27,8 +27,9 @@ def no_git_env():
     # while running pre-commit hooks in submodules.
     # GIT_DIR: Causes git clone to clone wrong thing
     # GIT_INDEX_FILE: Causes 'error invalid object ...' during commit
+    _env = _env if _env is not None else os.environ
     return {
-        k: v for k, v in os.environ.items()
+        k: v for k, v in _env.items()
         if not k.startswith('GIT_') or
         k in {'GIT_EXEC_PATH', 'GIT_SSH', 'GIT_SSH_COMMAND'}
     }
@@ -83,19 +84,24 @@ def get_conflicted_files():
     # If they resolved the merge conflict by choosing a mesh of both sides
     # this will also include the conflicted files
     tree_hash = cmd_output('git', 'write-tree')[1].strip()
-    merge_diff_filenames = zsplit(cmd_output(
-        'git', 'diff', '--name-only', '--no-ext-diff', '-z',
-        '-m', tree_hash, 'HEAD', 'MERGE_HEAD',
-    )[1])
+    merge_diff_filenames = zsplit(
+        cmd_output(
+            'git', 'diff', '--name-only', '--no-ext-diff', '-z',
+            '-m', tree_hash, 'HEAD', 'MERGE_HEAD',
+        )[1],
+    )
     return set(merge_conflict_filenames) | set(merge_diff_filenames)
 
 
-def get_staged_files():
-    return zsplit(cmd_output(
-        'git', 'diff', '--staged', '--name-only', '--no-ext-diff', '-z',
-        # Everything except for D
-        '--diff-filter=ACMRTUXB',
-    )[1])
+def get_staged_files(cwd=None):
+    return zsplit(
+        cmd_output(
+            'git', 'diff', '--staged', '--name-only', '--no-ext-diff', '-z',
+            # Everything except for D
+            '--diff-filter=ACMRTUXB',
+            cwd=cwd,
+        )[1],
+    )
 
 
 def intent_to_add_files():
@@ -117,10 +123,12 @@ def get_all_files():
 
 
 def get_changed_files(new, old):
-    return zsplit(cmd_output(
-        'git', 'diff', '--name-only', '--no-ext-diff', '-z',
-        '{}...{}'.format(old, new),
-    )[1])
+    return zsplit(
+        cmd_output(
+            'git', 'diff', '--name-only', '--no-ext-diff', '-z',
+            '{}...{}'.format(old, new),
+        )[1],
+    )
 
 
 def head_rev(remote):
@@ -135,6 +143,15 @@ def has_diff(*args, **kwargs):
     return cmd_output(*cmd, cwd=repo, retcode=None)[0]
 
 
+def init_repo(path, remote):
+    if os.path.isdir(remote):
+        remote = os.path.abspath(remote)
+
+    env = no_git_env()
+    cmd_output('git', 'init', path, env=env)
+    cmd_output('git', 'remote', 'add', 'origin', remote, cwd=path, env=env)
+
+
 def commit(repo='.'):
     env = no_git_env()
     name, email = 'pre-commit', 'asottile+pre-commit@umich.edu'
